@@ -49,7 +49,7 @@
 #include <QTimer>
 #include <QResizeEvent>
 #include <QApplication>
-#include <qinputdialog.h>
+#include <QInputDialog>
 #include <QColorDialog>
 #include <QComboBox>
 #include <QMenu>
@@ -603,7 +603,7 @@ void ResourceSelector::showInfo()
                              name, id, calType, alarmTypeString, storage, location, perms, enabled, std);
         // Display the collection information. Because the user requested
         // the information, don't raise a KNotify event.
-        KAMessageBox::information(this, text, QString(), QString(), nullptr);
+        KAMessageBox::information(this, text, QString(), QString(), KMessageBox::Options());
     }
 }
 
